==========================
 Contributors to ``haas``
==========================

- Ioannis Tziakos
- John Vandenberg
- Joris Vankerschaver
- Mark Dickinson
- Michael Overmeyer
- Mikalai Saskavets
- Simon Jagoe
